/*
 * This file is part of the LibreOffice project.
 *
 * Based on LLVM/Clang.
 *
 * This file is distributed under the University of Illinois Open Source
 * License. See LICENSE.TXT for details.
 *
 */

#include "demo.hxx"

namespace loplugin
{

/*

*/
Demo::Demo( ASTContext& context, Rewriter& rewriter )
    : RewritePlugin( context, rewriter )
    {
    }

void Demo::run()
    {
    TraverseDecl( context.getTranslationUnitDecl());
    }

bool Demo::VisitCXXMemberCallExpr( CXXMemberCallExpr* call )
    {
    if( ignoreLocation( call ))
        return true;
    const MemberExpr* member = dyn_cast< MemberExpr >( call->getCallee());
    if( member == NULL )
        {
        report( DiagnosticsEngine::Warning, "cannot analyse function call [loplugin]", call->getLocStart());
        call->dump();
        return true;
        }
    const CXXMethodDecl* method = dyn_cast< CXXMethodDecl >( member->getMemberDecl());
    if( method == NULL )
        {
        report( DiagnosticsEngine::Warning, "cannot analyse function call [loplugin]", call->getLocStart());
        call->dump();
        return true;
        }
    if( method->getQualifiedNameAsString() == "A::foo" )
        replaceText( SourceRange( member->getMemberLoc(), member->getLocEnd()), "bar" );
    return true;
    }

} // namespace
